#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

#include "view_options.h"
#include "file_selection.h"
#include "interface.h"
#include "settings.h"
#include "configuration.h"
#include "autorefresh.h"
#include "about.h"
#include "xmlconfig.h"
#include "refresh.h"
#include "international.h"
#include "layouts.h"


#define		OPEN_XML_FILE_CONFIG		ret = checkConfig (path_config); \
																if (ERRCONF == ret) \
																{ \
																	puts ("ERROR"); \
																	exit (1); \
																} \
																initWriteConfig (path_config);
																
#define		CLOSE_XML_FILE_CONFIG		destroyWriteConfig (path_config, 0);



/* layouts */
extern GtkListStore *command_info_table;
extern GtkListStore *liststore_left_command_column;
extern GPtrArray *list_layout2_table;
extern GPtrArray *list_command_name;
extern GtkWidget *vbox_right_panel_side;
extern GtkWidget *view_left_command_column;
extern guint temp_l2elem_selected;

/* refresh */
extern gint num_command;
extern gint append_num;

/* configuration */
extern gboolean tmp_check_buts_conf;

/* list_int_addr */
extern GPtrArray *tmp_add_list;

/* main */
extern gchar *path_config;

/* extern */
GtkWidget *window1;		/* main window */
GtkWidget *entry[24];
GtkWidget *save_view_options_too1;
GtkWidget *save_at_refresh1;
GtkWidget *save_as2;
GtkWidget *scrolledwindow;
GtkWidget *hpaned;
GtkWidget *statusbar;
GtkWidget *handlebox;
gchar *path;
gchar *commands_lsof;

gboolean first_save_at_refresh_call;

gboolean view_menu_toolbar;
gboolean view_menu_statusbar;
gboolean view_menu_singledoublelist;
/* _extern */


/* signals interface */

void
on_refresh_clicked (GtkButton * button, gpointer user_data)
{
  gint i;

  /* clean lists */

  gtk_list_store_clear (command_info_table);
  gtk_list_store_clear (liststore_left_command_column);
	
  /* free list_command_name array */
	
  i = list_command_name->len - 1;
	
  if (i >= 0)
  {   
	  for (; i < 0; i--)
		  g_free (g_ptr_array_index(list_command_name, i));
		  
	  list_command_name = g_ptr_array_sized_new (0);
  }
  
  
  /* free list_layout2_table array */
  
  i = list_layout2_table->len - 1;
  
  if (i >= 0)
  {  
	  gtk_widget_destroy (vbox_right_panel_side);
	  vbox_right_panel_side = gtk_vbox_new (FALSE, 0);
	  gtk_widget_show (vbox_right_panel_side);
  	  gtk_paned_pack2 (GTK_PANED (hpaned), vbox_right_panel_side, TRUE, TRUE);
	  
	  for (; i < 0; i--)
		  g_free (g_ptr_array_index(list_layout2_table, i));
	  
	  list_layout2_table = g_ptr_array_sized_new (0);
  }
  
  /* refresh */
  
  num_command = 0;
  update_clist ();
}

static void
wrap_load_sets (GtkButton * button, gpointer user_data)
{
  load_sets(path_config);
}

static void
wrap_save_sets (GtkButton * button, gpointer user_data)
{
  save_sets(path_config);
}

static void
on_window1_destroy (GtkObject * object, gpointer user_data)
{
  gint i;

  /* free memory */ 
  g_ptr_array_free (tmp_add_list,FALSE);
	
  for (i=list_command_name->len-1; i>=0; i--)
	  g_ptr_array_remove_index (list_command_name, i);
  	
  g_ptr_array_free (list_command_name,FALSE);
	
  /* save x-y and main window size */
  if (tmp_check_buts_conf)
    on_configuration_ok (NULL, NULL);
  
  gtk_main_quit ();
}

static void 
on_item_layout1_activate (GtkButton * button, gpointer user_data)
{
	gchar buf [256];
	guint ret;
	
	gtk_widget_show (scrolledwindow);
	gtk_widget_hide (hpaned);
	
	/* show number of processes and lines in status bar */
  
  	gtk_statusbar_pop (GTK_STATUSBAR(statusbar),1);
  	g_snprintf(buf, 256, "Processes: %d\tTotal Lines: %d",list_command_name->len,append_num);
  	gtk_statusbar_push (GTK_STATUSBAR (statusbar), 1, &buf[0]);
	
	OPEN_XML_FILE_CONFIG
	setShowSingledoublelist(1);
	CLOSE_XML_FILE_CONFIG
}

static void 
on_item_layout2_activate (GtkButton * button, gpointer user_data)
{
	guint ret;
	guint len;
	
	gtk_widget_show (hpaned);
	gtk_widget_hide (scrolledwindow);
	
	len = list_command_name->len;
	
	if ( len > 0)
	{
		gchar buf[256];
		layout2_elem *elem;
		
		elem = g_ptr_array_index (list_layout2_table, temp_l2elem_selected);
		
		/* show line numbers in status bar */
		
		gtk_statusbar_pop (GTK_STATUSBAR(statusbar),1);
		g_snprintf(buf, 256, "Lines: %d\tTotal Lines: %d", elem->lines,append_num);
		gtk_statusbar_push (GTK_STATUSBAR(statusbar),1,&buf[0]);
		
		/* set focus */
		
		gtk_widget_grab_focus (GTK_WIDGET (view_left_command_column));
	}
	
	OPEN_XML_FILE_CONFIG
	setShowSingledoublelist(0);
	CLOSE_XML_FILE_CONFIG
}

static void 
on_view_toolbar_menu_toggled (GtkCheckMenuItem *checkmenuitem,
                                            gpointer user_data)
{
	guint ret;
	gboolean state = gtk_check_menu_item_get_active (checkmenuitem);
	
	if (state)
		gtk_widget_show (handlebox);
	else
		gtk_widget_hide (handlebox);
	
	OPEN_XML_FILE_CONFIG
	setShowToolbar(state);
	CLOSE_XML_FILE_CONFIG
}

static void 
on_view_statusbar_menu_toggled (GtkCheckMenuItem *checkmenuitem,
                                            gpointer user_data)
{
	guint ret;
	gboolean state = gtk_check_menu_item_get_active (checkmenuitem);
	
	if (state)
		gtk_widget_show (statusbar);
	else
		gtk_widget_hide (statusbar);
	
	OPEN_XML_FILE_CONFIG
	setShowStatusbar(state);
	CLOSE_XML_FILE_CONFIG
}


/* Main Window */

GtkWidget *
create_window1 (void)
{
  GtkWidget *vbox;
  GtkWidget *menubar;
  GtkWidget *menuitem;
  GtkWidget *menuitem_menu;
  GtkWidget *load_settings1;
  GtkWidget *load_settings_from1;
  GtkWidget *separatore;
  GtkWidget *save_settings1;
  GtkWidget *save_settings_as1;
  GtkWidget *quit2;
  GtkWidget *view_options1;
  GtkWidget *settings1;
  GtkWidget *configuration1;
  GtkWidget *refresh1;
  GtkWidget *autorefresh1;
  GtkWidget *about1;
  GSList *item_layout_group = NULL;
  GtkWidget *item_layout1;
  GtkWidget *item_layout2;
  GtkWidget *view_toolbar_menu;
  GtkWidget *view_statusbar_menu;
	
  /* toolbar widgets */
  GtkWidget *toolbar;
  GtkWidget *tmp_image;
  GtkWidget *toolbutton1;
  GtkWidget *toolbutton2;
  GtkWidget *toolbutton3;
  GtkWidget *toolbutton4;
  GtkWidget *toolbutton5;
  GtkWidget *toolbutton6;
  GtkWidget *toolbutton7;
  GtkWidget *toolbutton8;
  
  gint tmp_toolbar_icon_size;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (window1), (_("GLSOF (Big Brother)") ));
  gtk_window_resize (GTK_WINDOW (window1), 700, 525);
  gtk_widget_realize (window1);
  gtk_window_add_accel_group (GTK_WINDOW (window1), accel_group);

  vbox = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox);
  gtk_container_add (GTK_CONTAINER (window1), vbox);
  
  /********************************/
  /*             MENU             */
  /********************************/

  menubar = gtk_menu_bar_new ();
  gtk_widget_show (menubar);
  gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
  
  /********************************/
  /*             FILE             */
  /********************************/

  menuitem = gtk_menu_item_new_with_mnemonic (_("_File"));
  gtk_widget_show (menuitem);
  gtk_container_add (GTK_CONTAINER (menubar), menuitem);

  menuitem_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menuitem_menu);

  load_settings1 = gtk_image_menu_item_new_with_mnemonic (_("_Load Settings"));
  gtk_widget_show (load_settings1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), load_settings1);
  gtk_widget_add_accelerator (load_settings1, "activate", accel_group,
			      GDK_L, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  tmp_image = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_MENU);
  gtk_widget_show (tmp_image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (load_settings1), tmp_image);

  load_settings_from1 =
    gtk_menu_item_new_with_mnemonic (_("Load Settings From..."));
  gtk_widget_show (load_settings_from1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), load_settings_from1);

  separatore = gtk_menu_item_new ();
  gtk_widget_show (separatore);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), separatore);
  gtk_widget_set_sensitive (separatore, FALSE);

  save_settings1 = gtk_image_menu_item_new_with_mnemonic (_("_Save Settings"));
  gtk_widget_show (save_settings1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), save_settings1);
  gtk_widget_add_accelerator (save_settings1, "activate", accel_group,
			      GDK_S, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  tmp_image = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_show (tmp_image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (save_settings1), tmp_image);

  save_settings_as1 =
    gtk_menu_item_new_with_mnemonic (_("Save Settings As..."));
  gtk_widget_show (save_settings_as1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), save_settings_as1);

  save_view_options_too1 =
    gtk_check_menu_item_new_with_mnemonic (_("Save View Options too"));
  gtk_widget_show (save_view_options_too1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), save_view_options_too1);

  separatore = gtk_menu_item_new ();
  gtk_widget_show (separatore);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), separatore);
  gtk_widget_set_sensitive (separatore, FALSE);

  quit2 = gtk_image_menu_item_new_from_stock ("gtk-quit", accel_group);
  gtk_widget_show (quit2);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), quit2);
  gtk_widget_add_accelerator (quit2, "activate", accel_group,
			      GDK_Q, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  /********************************/
  /*             EDIT             */
  /********************************/

  menuitem = gtk_menu_item_new_with_mnemonic (_("_Edit"));
  gtk_widget_show (menuitem);
  gtk_container_add (GTK_CONTAINER (menubar), menuitem);

  menuitem_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menuitem_menu);

  view_options1 = gtk_image_menu_item_new_with_mnemonic (_("View Options"));
  gtk_widget_show (view_options1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), view_options1);
  gtk_widget_add_accelerator (view_options1, "activate", accel_group,
			      GDK_V, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  tmp_image = gtk_image_new_from_stock ("gtk-cut", GTK_ICON_SIZE_MENU);
  gtk_widget_show (tmp_image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (view_options1), tmp_image);

  settings1 = gtk_image_menu_item_new_with_mnemonic (_("Settings"));
  gtk_widget_show (settings1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), settings1);
  gtk_widget_add_accelerator (settings1, "activate", accel_group,
			      GDK_E, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  tmp_image = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_show (tmp_image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (settings1), tmp_image);

  configuration1 = gtk_image_menu_item_new_with_mnemonic (_("Configuration"));
  gtk_widget_show (configuration1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), configuration1);
  gtk_widget_add_accelerator (configuration1, "activate", accel_group,
			      GDK_C, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  tmp_image = gtk_image_new_from_stock ("gtk-properties", GTK_ICON_SIZE_MENU);
  gtk_widget_show (tmp_image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (configuration1), tmp_image);
				  
  /********************************/
  /*            VIEW              */
  /********************************/
  
  menuitem = gtk_menu_item_new_with_mnemonic (_("_View"));
  gtk_widget_show (menuitem);
  gtk_container_add (GTK_CONTAINER (menubar), menuitem);

  menuitem_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menuitem_menu);
  
  view_toolbar_menu =
    gtk_check_menu_item_new_with_mnemonic (_("Show Toolbar Menu"));
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_toolbar_menu), view_menu_toolbar);
  gtk_widget_show (view_toolbar_menu);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), view_toolbar_menu);
  
  view_statusbar_menu =
    gtk_check_menu_item_new_with_mnemonic (_("Show Statusbar"));
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_statusbar_menu), view_menu_statusbar);
  gtk_widget_show (view_statusbar_menu);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), view_statusbar_menu);
  
  separatore = gtk_menu_item_new ();
  gtk_widget_show (separatore);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), separatore);
  gtk_widget_set_sensitive (separatore, FALSE);

  item_layout1 = gtk_radio_menu_item_new_with_mnemonic (item_layout_group, _("Show Single List"));
  item_layout_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item_layout1));
  gtk_widget_show (item_layout1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), item_layout1);

  item_layout2 = gtk_radio_menu_item_new_with_mnemonic (item_layout_group, _("Show Double List"));
  item_layout_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item_layout2));
  gtk_widget_show (item_layout2);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), item_layout2);
  
				  
  /********************************/
  /*            OUTPUT            */
  /********************************/

  menuitem = gtk_menu_item_new_with_mnemonic (_("_Output"));
  gtk_widget_show (menuitem);
  gtk_container_add (GTK_CONTAINER (menubar), menuitem);

  menuitem_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menuitem_menu);

  refresh1 = gtk_image_menu_item_new_with_mnemonic (_("Refresh"));
  gtk_widget_show (refresh1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), refresh1);
  gtk_widget_add_accelerator (refresh1, "activate", accel_group,
			      GDK_R, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  tmp_image = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_show (tmp_image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (refresh1), tmp_image);
				  
  autorefresh1 = gtk_menu_item_new_with_mnemonic (_("Auto Refresh"));
  gtk_widget_show (autorefresh1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), autorefresh1);
  gtk_widget_add_accelerator (autorefresh1, "activate", accel_group,
			      GDK_A, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);

  separatore = gtk_menu_item_new ();
  gtk_widget_show (separatore);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), separatore);
  gtk_widget_set_sensitive (separatore, FALSE);

  save_as2 = gtk_image_menu_item_new_with_mnemonic (_("Save As..."));
  gtk_widget_show (save_as2);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), save_as2);
  gtk_widget_add_accelerator (save_as2, "activate", accel_group,
			      GDK_O, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
				  
  tmp_image = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_show (tmp_image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (save_as2), tmp_image);

  save_at_refresh1 =
    gtk_check_menu_item_new_with_mnemonic (_("Save At Refresh..."));
  gtk_widget_show (save_at_refresh1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), save_at_refresh1);

  /********************************/
  /*             HELP             */
  /********************************/

  menuitem = gtk_menu_item_new_with_mnemonic (_("_Help"));
  gtk_widget_show (menuitem);
  gtk_container_add (GTK_CONTAINER (menubar), menuitem);
  gtk_menu_item_set_right_justified (GTK_MENU_ITEM (menuitem), TRUE);

  menuitem_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menuitem_menu);

  about1 = gtk_image_menu_item_new_from_stock ("gtk-dialog-info", accel_group);
  gtk_widget_show (about1);
  gtk_container_add (GTK_CONTAINER (menuitem_menu), about1);

  /********************************/
  /*           END MENU           */
  /********************************/
  
  
  /********************************/
  /*      START TOOLBAR MENU      */
  /********************************/
  
  handlebox = gtk_handle_box_new ();
  gtk_box_pack_start (GTK_BOX (vbox), handlebox, FALSE, FALSE, 0);

  toolbar = gtk_toolbar_new ();
  gtk_widget_show (toolbar);
  gtk_container_add (GTK_CONTAINER (handlebox), toolbar);
  gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_BOTH);
  tmp_toolbar_icon_size = gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar));

  tmp_image = gtk_image_new_from_stock ("gtk-save", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  toolbutton1 = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Save Settings"));
  gtk_widget_show (toolbutton1);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton1);

  toolbutton2 = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-quit");
  gtk_widget_show (toolbutton2);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton2);

  separatore = (GtkWidget*) gtk_separator_tool_item_new ();
  gtk_widget_show (separatore);
  gtk_container_add (GTK_CONTAINER (toolbar), separatore);

  tmp_image = gtk_image_new_from_stock ("gtk-refresh", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  toolbutton3 = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Refresh"));
  gtk_widget_show (toolbutton3);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton3);

  tmp_image = gtk_image_new_from_stock ("gtk-save-as", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  toolbutton4 = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Save Output"));
  gtk_widget_show (toolbutton4);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton4);

  separatore = (GtkWidget*) gtk_separator_tool_item_new ();
  gtk_widget_show (separatore);
  gtk_container_add (GTK_CONTAINER (toolbar), separatore);

  tmp_image = gtk_image_new_from_stock ("gtk-cut", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  toolbutton5 = (GtkWidget*) gtk_tool_button_new (tmp_image, _("View Options"));
  gtk_widget_show (toolbutton5);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton5);

  tmp_image = gtk_image_new_from_stock ("gtk-preferences", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  toolbutton6 = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Settings"));
  gtk_widget_show (toolbutton6);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton6);

  tmp_image = gtk_image_new_from_stock ("gtk-properties", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  toolbutton7 = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Configuration"));
  gtk_widget_show (toolbutton7);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton7);

  separatore = (GtkWidget*) gtk_separator_tool_item_new ();
  gtk_widget_show (separatore);
  gtk_container_add (GTK_CONTAINER (toolbar), separatore);

  tmp_image = gtk_image_new_from_stock ("gtk-refresh", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  toolbutton8 = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Auto Refresh"));
  gtk_widget_show (toolbutton8);
  gtk_container_add (GTK_CONTAINER (toolbar), toolbutton8);
  
  /********************************/
  /*       END TOOLBAR MENU       */
  /********************************/
  
  /* show layout */
  
  scrolledwindow = make_layout_1 (vbox);
  hpaned = make_layout_2 (vbox);
  
  gtk_widget_hide (hpaned);
  gtk_widget_show (scrolledwindow);
  
  /* show status bar */
  
  statusbar = gtk_statusbar_new();
  gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
	
  /* make array of pointers for 'list addresses' interface */

  tmp_add_list = g_ptr_array_new ();
  list_layout2_table = g_ptr_array_new ();
  list_command_name = g_ptr_array_new ();
	
  /* define signals for main interface */

  g_signal_connect ((gpointer) load_settings1, "activate",
		    G_CALLBACK (wrap_load_sets), NULL);
  g_signal_connect ((gpointer) load_settings_from1, "activate",
		    G_CALLBACK (on_save_as_clicked), GINT_TO_POINTER (2));
  g_signal_connect ((gpointer) save_settings1, "activate",
		    G_CALLBACK (wrap_save_sets), NULL);
  g_signal_connect ((gpointer) save_settings_as1, "activate",
		    G_CALLBACK (on_save_as_clicked), GINT_TO_POINTER (1));
  
  g_signal_connect ((gpointer) quit2, "activate",
		    G_CALLBACK (on_window1_destroy), NULL);
  g_signal_connect ((gpointer) view_options1, "activate",
		    G_CALLBACK (on_preferences_clicked), NULL);
  g_signal_connect ((gpointer) settings1, "activate",
		    G_CALLBACK (on_settings_clicked), NULL);
  g_signal_connect ((gpointer) configuration1, "activate",
		    G_CALLBACK (on_configuration_clicked), NULL);
  g_signal_connect ((gpointer) refresh1, "activate",
		    G_CALLBACK (on_refresh_clicked), NULL);
  g_signal_connect ((gpointer) autorefresh1, "activate",
		    G_CALLBACK (on_autorefresh_clicked), NULL);
  g_signal_connect ((gpointer) save_as2, "activate",
		    G_CALLBACK (on_save_as_clicked), GINT_TO_POINTER (0));
  g_signal_connect ((gpointer) about1, "activate",
		    G_CALLBACK (on_info_clicked), NULL);
			
  /* menu view */
  
  g_signal_connect ((gpointer) view_toolbar_menu, "toggled",
		    G_CALLBACK (on_view_toolbar_menu_toggled), NULL);
  g_signal_connect ((gpointer) view_statusbar_menu, "toggled",
		    G_CALLBACK (on_view_statusbar_menu_toggled), NULL);
  g_signal_connect ((gpointer) item_layout1, "activate",
            G_CALLBACK (on_item_layout1_activate), NULL);
  g_signal_connect ((gpointer) item_layout2, "activate",
            G_CALLBACK (on_item_layout2_activate), NULL);  
			
  /* signals for toolbar */
  
  g_signal_connect ((gpointer) toolbutton1, "clicked",
            G_CALLBACK (wrap_save_sets), NULL);
  g_signal_connect ((gpointer) toolbutton2, "clicked",
            G_CALLBACK (on_window1_destroy), NULL);
  g_signal_connect ((gpointer) toolbutton3, "clicked",
            G_CALLBACK (on_refresh_clicked), NULL);
  g_signal_connect ((gpointer) toolbutton4, "clicked",
            G_CALLBACK (on_save_as_clicked), NULL);
  g_signal_connect ((gpointer) toolbutton5, "clicked",
            G_CALLBACK (on_preferences_clicked), NULL);
  g_signal_connect ((gpointer) toolbutton6, "clicked",
            G_CALLBACK (on_settings_clicked), NULL);
  g_signal_connect ((gpointer) toolbutton7, "clicked",
            G_CALLBACK (on_configuration_clicked), NULL);
  g_signal_connect ((gpointer) toolbutton8, "clicked",
            G_CALLBACK (on_autorefresh_clicked), NULL);
					
  /* exit from glsof */
  g_signal_connect ((gpointer) window1, "delete-event",
		    G_CALLBACK (on_window1_destroy), NULL);

  /* load all sets from xml file configuration.xml */
  load_sets (path_config);
  
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_toolbar_menu), view_menu_toolbar);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_statusbar_menu), view_menu_statusbar);
  
  if (view_menu_singledoublelist == TRUE)
	  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item_layout1), TRUE);
  else
	  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item_layout2), TRUE);

  /* launch first automatic refresh*/
  on_refresh_clicked (NULL,NULL);

  return window1;
}
