#include <gtk/gtk.h>

#include "layouts.h"

/* refresh */
extern GPtrArray *list_layout2_table;
extern guint append_num;

/* interface */
extern GtkWidget *statusbar;

/* extern */
GtkWidget *view;
GtkWidget *vbox_right_panel_side;
GtkListStore *liststore_left_command_column;
GtkListStore *command_info_table;
GtkWidget *view_left_command_column;

guint temp_l2elem_selected;

gchar *name_fields[] = {
  "COMMAND       ", "PID    ", "PGID    ", "PPID  ", "USER      ", "FD   ",
  "TYPE      ", "DEVICE    ", "SIZE     ", "NLINK   ", "NODE  ", "NAME"
};


/********************************/
/*           LAYOUT 1           */
/********************************/

GtkWidget *
make_layout_1 (GtkWidget *vbox1)
{
  GtkTreeSelection *selection;
  GtkCellRenderer *cell;
  GtkTreeViewColumn *column;
  GtkWidget *scrolledwindow1;
	
  int i = 0;

  /* scrolled window for main list */
  
  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_container_add (GTK_CONTAINER (vbox1), scrolledwindow1);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1),
				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow1),
				       GTK_SHADOW_OUT);
					   
  /* make main column-list */
  
  view = gtk_tree_view_new ();
  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));

  gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
  command_info_table = gtk_list_store_new (12, \
  										   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, \
  										   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);

  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);	/* white - grey alternate */
  
  gtk_tree_view_set_model (GTK_TREE_VIEW (view),
				 GTK_TREE_MODEL (command_info_table));

  
  for (i = 0; i < 12; i++)
    {
		cell = gtk_cell_renderer_text_new ();
		column = gtk_tree_view_column_new_with_attributes(name_fields[i], cell, "text", i, NULL);
		gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
		
		if ( (i==0) || (i==11) )
			gtk_tree_view_column_set_sort_column_id(column, i);
		
		gtk_tree_view_append_column(GTK_TREE_VIEW(view), column);
	}
	
  gtk_widget_show (view);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), view);
	
  return scrolledwindow1;
}


/********************************/
/*           LAYOUT 2           */
/********************************/

/* get row from menu */
static void
selection_changed_layout_table (GtkTreeSelection * selection, gpointer data)
{
	GtkTreeModel *model;
	GtkTreeIter iter;

	if (gtk_tree_selection_get_selected (selection, &model, &iter))
	{
		GtkTreePath *path;
		layout2_elem *elem;
		
		gchar buf[256];
		
		path = gtk_tree_model_get_path (model, &iter);
		
		elem = g_ptr_array_index (list_layout2_table, temp_l2elem_selected);
		gtk_widget_hide (elem->scrolledwindow);
		
		temp_l2elem_selected = gtk_tree_path_get_indices (path)[0];
		elem = g_ptr_array_index (list_layout2_table, temp_l2elem_selected);
		gtk_widget_show (elem->scrolledwindow);
		
		gtk_tree_path_free (path);
		
		/* show line numbers in status bar */
		
		gtk_statusbar_pop (GTK_STATUSBAR(statusbar),1);
		g_snprintf(buf, 256, "Lines: %d\tTotal Lines: %d", elem->lines,append_num);
		gtk_statusbar_push (GTK_STATUSBAR (statusbar), 1, &buf[0]);
	}
}				/* _selection_changed */


GtkWidget *
make_layout_2 (GtkWidget *vbox1)
{
  GtkWidget *hpaned1;
  GtkTreeSelection *selection_left_command_column;
  GtkCellRenderer *cell_left_command_column;
  GtkWidget *scrolledwindow1;
  GtkTreeViewColumn *column;
	
  /* add horizontal panel */
  
  hpaned1 = gtk_hpaned_new ();
  gtk_container_add (GTK_CONTAINER (vbox1), hpaned1);
  gtk_paned_set_position (GTK_PANED (hpaned1),150);
  
  /* add left COMMAND's columm */
  
  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow1);
  gtk_paned_pack1 (GTK_PANED (hpaned1), scrolledwindow1, FALSE, TRUE);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1),
				GTK_POLICY_AUTOMATIC,
				GTK_POLICY_AUTOMATIC);
  
  view_left_command_column = gtk_tree_view_new ();
  selection_left_command_column = gtk_tree_view_get_selection (GTK_TREE_VIEW (view_left_command_column));

  gtk_tree_selection_set_mode (selection_left_command_column, GTK_SELECTION_SINGLE);
  liststore_left_command_column = gtk_list_store_new (2, G_TYPE_INT, G_TYPE_STRING);

  gtk_tree_view_set_model (GTK_TREE_VIEW (view_left_command_column),
			 GTK_TREE_MODEL (liststore_left_command_column));

  cell_left_command_column = gtk_cell_renderer_text_new ();
  column = gtk_tree_view_column_new_with_attributes ("  #  ", cell_left_command_column, "text", 0, NULL);
  gtk_tree_view_append_column(GTK_TREE_VIEW(view_left_command_column), column);
						 
  gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);

  cell_left_command_column = gtk_cell_renderer_text_new ();
  column = gtk_tree_view_column_new_with_attributes ("COMMAND", cell_left_command_column, "text", 1, NULL);
  gtk_tree_view_append_column(GTK_TREE_VIEW(view_left_command_column), column);
						 
  gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);

  gtk_widget_show (view_left_command_column);
	
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), view_left_command_column);
  
  /* second panel side */
  
  vbox_right_panel_side = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox_right_panel_side);
  gtk_paned_pack2 (GTK_PANED (hpaned1), vbox_right_panel_side, TRUE, TRUE);
  
  /* signals */
  
  g_signal_connect (G_OBJECT (selection_left_command_column), "changed", 
  			  G_CALLBACK (selection_changed_layout_table), NULL);
  
  return hpaned1;
}
